@@ -43,22 +43,22 @@
 #include <tqvbuttongroup.h>
 #include <tqwidgetstack.h>
 
-#include <kabc/addressee.h>
-#include <kabc/addresseelist.h>
-#include <kabc/addressbook.h>
-#include <kabc/stdaddressbook.h>
-#include <kapplication.h>
+#include <tdeabc/addressee.h>
+#include <tdeabc/addresseelist.h>
+#include <tdeabc/addressbook.h>
+#include <tdeabc/stdaddressbook.h>
+#include <tdeapplication.h>
 #include <kcombobox.h>
 #include <kcompletion.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
 #include <kimageio.h>
 #include <klineedit.h>
-#include <klistbox.h>
-#include <klistview.h>
-#include <kmessagebox.h>
+#include <tdelistbox.h>
+#include <tdelistview.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kpushbutton.h>
 #include <kurlrequester.h>
 #include <tqtable.h>
@@ -66,22 +66,22 @@
 
 #define PNG_FORMAT "PNG"
 
-class AddressListViewItem : public KListViewItem {
+class AddressListViewItem : public TDEListViewItem {
 public:
-    AddressListViewItem(TQListView *parent, KABC::Addressee & addr )
-        : KListViewItem( parent ), m_address( addr )
+    AddressListViewItem(TQListView *parent, TDEABC::Addressee & addr )
+        : TDEListViewItem( parent ), m_address( addr )
         {
             this->setText( 0, m_address.givenName() );
             this->setText( 1, m_address.familyName() );
             this->setText( 2, m_address.preferredEmail() );
         }
     
-    const KABC::Addressee & address() const {
+    const TDEABC::Addressee & address() const {
         return m_address;
     }
 
 private:
-    KABC::Addressee m_address;
+    TDEABC::Addressee m_address;
 
 };
 
@@ -96,7 +96,7 @@ BatchWizard::BatchWizard( TQWidget* parent, const char* name )
     setupPage5();
     setupPage10();
 
-    compGroup = new KCompletion();
+    compGroup = new TDECompletion();
 
     enableControls();
     setupSql();
@@ -185,7 +185,7 @@ void BatchWizard::setupPage4()
     buttonTableInsert = new KPushButton( i18n("Insert Row"), hbox );
     buttonTableInsert->setIconSet( BarIconSet( "edit" ) );
     buttonTableRemove = new KPushButton( i18n("Delete Row"), hbox );
-    buttonTableRemove->setIconSet( BarIconSet( "editdelete") );
+    buttonTableRemove->setIconSet( BarIconSet( "edit-delete") );
 
     m_varTable = new TQTable( page4 );
     m_varTable->setReadOnly( false );
@@ -308,13 +308,13 @@ void BatchWizard::setupStackPage1()
     buttonRemove = new KPushButton( i18n("&Remove" ), hButtonBox );
     buttonRemoveAll = new KPushButton( i18n("R&emove All"), hButtonBox );
 
-    KPopupMenu* mnuImport = new KPopupMenu( this );
+    TDEPopupMenu* mnuImport = new TDEPopupMenu( this );
     mnuImport->insertItem( i18n("Import from File ..."), this, TQT_SLOT( loadFromFile() ) );
     mnuImport->insertItem( i18n("Import from Clipboard ..."), this, TQT_SLOT( loadFromClipboard() ) );
     mnuImport->insertItem( i18n("Import barcode_basic"), this, TQT_SLOT( addAllItems() ) );
     buttonImport->setPopup( mnuImport );
 
-    sqlList = new KListView( stack1 );
+    sqlList = new TDEListView( stack1 );
     sqlList->addColumn( i18n("Index") );
     sqlList->addColumn( i18n("Number of Labels") );
     sqlList->addColumn( i18n("Article Number") );
@@ -360,7 +360,7 @@ void BatchWizard::setupStackPage2()
     box->setSpacing( 5 );
 
     new TQLabel( i18n("Available Variables:"), box );
-    m_varList = new KListBox( box );
+    m_varList = new TDEListBox( box );
 
     connect( radioImportManual, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
     connect( radioImportSql, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
@@ -430,7 +430,7 @@ void BatchWizard::setupStackPage4()
     new TQLabel( i18n("All Addresses"), list1 );
     new TQLabel( i18n("Selected Addresses"), list2 );
 
-    listAddress = new KListView( list1 );
+    listAddress = new TDEListView( list1 );
     listAddress->addColumn( i18n("Given Name"), 0 );
     listAddress->addColumn( i18n("Family Name"), 1 );
     listAddress->addColumn( i18n("Email Address"), 2 );
@@ -441,7 +441,7 @@ void BatchWizard::setupStackPage4()
     listAddress->setColumnWidthMode( 1, TQListView::Maximum );
     listAddress->setColumnWidthMode( 2, TQListView::Maximum );
 
-    listSelectedAddress = new KListView( list2 );
+    listSelectedAddress = new TDEListView( list2 );
     listSelectedAddress->addColumn( i18n("Given Name"), 0 );
     listSelectedAddress->addColumn( i18n("Family Name"), 1 );
     listSelectedAddress->addColumn( i18n("Email Address"), 2 );
@@ -614,9 +614,9 @@ void BatchWizard::printNow( const TQString & printer, bool bUserInteraction )
     if( !checkKeepOpen->isChecked() )
         KWizard::accept();
 
-    KApplication::setOverrideCursor( TQCursor( TQt::ArrowCursor ), true );
+    TDEApplication::setOverrideCursor( TQCursor( TQt::ArrowCursor ), true );
     setupBatchPrinter( batch, batchType );
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 
     delete prn;
     delete batch;
@@ -699,7 +699,7 @@ void BatchWizard::setupBatchPrinter( BatchPrinter* batch, int m )
     }
     else if( radioAddressBook->isChecked() )
     {
-        KABC::AddresseeList* list = new KABC::AddresseeList;
+        TDEABC::AddresseeList* list = new TDEABC::AddresseeList;
         TQListViewItem* item = listSelectedAddress->firstChild();
         while( item ) 
         {
@@ -747,7 +747,7 @@ bool BatchWizard::addItem( const TQString & article, const TQString & group, int
     TQString temp;
     temp.sprintf("%0*i", 5, sqlList->childCount() + 1 );
 
-    KListViewItem* item = new KListViewItem( sqlList, temp, TQString( "%1" ).arg( count ),
+    TDEListViewItem* item = new TDEListViewItem( sqlList, temp, TQString( "%1" ).arg( count ),
                           article, group );
     sqlList->insertItem( item );
 
@@ -857,7 +857,7 @@ void BatchWizard::addAllItems()
 	while( query.next() ) 
 	{
 	    temp.sprintf("%0*i", 5, sqlList->childCount() + 1 );
-	    new KListViewItem( sqlList, temp, num, query.value( 0 ).toString(), group );
+	    new TDEListViewItem( sqlList, temp, num, query.value( 0 ).toString(), group );
 	}
 
         enableControls();
@@ -873,7 +873,7 @@ void BatchWizard::loadFromFile()
 
 void BatchWizard::loadFromClipboard() 
 {
-    TQClipboard *cb = KApplication::clipboard();
+    TQClipboard *cb = TDEApplication::clipboard();
     loadData( cb->text() );
 }
 
@@ -884,7 +884,7 @@ void BatchWizard::loadFromFile( const TQString & url )
     
     if( !file.open( IO_ReadOnly ) ) 
     {
-        qDebug("Unable to open file: %s", url.latin1() );
+        tqDebug("Unable to open file: %s", url.latin1() );
         return;
     }
 
@@ -903,7 +903,7 @@ void BatchWizard::loadData( const TQString & data )
     }
 
     // new config entry!!!
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("FileFormat");
     int pos[3] = { config->readNumEntry("Data0", 0 ),
                    config->readNumEntry("Data1", 1 ),
@@ -1026,10 +1026,10 @@ void BatchWizard::fillVarList()
 
 void BatchWizard::fillAddressList()
 {
-    KABC::AddressBook* ab = KABC::StdAddressBook::self();
+    TDEABC::AddressBook* ab = TDEABC::StdAddressBook::self();
     listAddress->clear();
     
-    KABC::AddressBook::Iterator it;
+    TDEABC::AddressBook::Iterator it;
     listAddress->setUpdatesEnabled( false );
     for ( it = ab->begin(); it != ab->end(); ++it ) 
         new AddressListViewItem( listAddress, *it );
